@@ -2,11 +2,16 @@ from typing import Any, Type
 
 import numpy as np
 
-from smac.epm.base_gp import BaseModel
-from smac.epm.gaussian_process_mcmc import GaussianProcess, GaussianProcessMCMC
-from smac.epm.gp_base_prior import HorseshoePrior, LognormalPrior
-from smac.epm.gp_kernels import ConstantKernel, HammingKernel, Matern, WhiteKernel
-from smac.epm.util_funcs import get_rng, get_types
+from smac.epm.gaussian_process import BaseModel, GaussianProcess
+from smac.epm.gaussian_process.kernels import (
+    ConstantKernel,
+    HammingKernel,
+    Matern,
+    WhiteKernel,
+)
+from smac.epm.gaussian_process.mcmc import MCMCGaussianProcess
+from smac.epm.gaussian_process.utils.prior import HorseshoePrior, LognormalPrior
+from smac.epm.utils import get_rng, get_types
 from smac.facade.smac_ac_facade import SMAC4AC
 from smac.initial_design.sobol_design import SobolDesign
 from smac.runhistory.runhistory2epm import RunHistory2EPM4Cost
@@ -132,7 +137,7 @@ class SMAC4BB(SMAC4AC):
                 model_kwargs["normalize_y"] = True
                 model_kwargs["seed"] = rng.randint(0, 2**20)
             elif model_type == "gp_mcmc":
-                model_class = GaussianProcessMCMC
+                model_class = MCMCGaussianProcess
                 kwargs["model"] = model_class
                 kwargs["integrate_acquisition_function"] = True
 
