@@ -1,6 +1,6 @@
 from typing import Any
 
-from smac.epm.rf_with_instances import RandomForestWithInstances
+from smac.epm.random_forest.rf_with_instances import RandomForestWithInstances
 from smac.facade.smac_ac_facade import SMAC4AC
 from smac.initial_design.sobol_design import SobolDesign
 from smac.optimizer.acquisition import LogEI
