@@ -7,12 +7,12 @@ import numpy as np
 
 from smac.configspace import convert_configurations_to_array
 from smac.epm.base_imputor import BaseImputor
-from smac.optimizer.multi_objective.aggregation_strategy import AggregationStrategy
+from smac.multi_objective.aggregation_strategy import AggregationStrategy
+from smac.multi_objective.utils import normalize_costs
 from smac.runhistory.runhistory import RunHistory, RunKey, RunValue
 from smac.scenario.scenario import Scenario
 from smac.tae import StatusType
 from smac.utils import constants
-from smac.utils.multi_objective import normalize_costs
 
 __author__ = "Katharina Eggensperger"
 __copyright__ = "Copyright 2015, ML4AAD"
@@ -473,7 +473,7 @@ class RunHistory2EPM4Cost(AbstractRunHistory2EPM):
 
                 # Let's normalize y here
                 # We use the objective_bounds calculated by the runhistory
-                y_ = normalize_costs([run.cost], runhistory.objective_bounds)
+                y_ = normalize_costs(run.cost, runhistory.objective_bounds)
                 y_agg = self.multi_objective_algorithm(y_)
                 y[row] = y_agg
             else:
@@ -489,7 +489,6 @@ class RunHistory2EPM4Cost(AbstractRunHistory2EPM):
                 self.max_y = np.max(y, axis=0)
 
         y = self.transform_response_values(values=y)
-
         return X, y
 
     def transform_response_values(self, values: np.ndarray) -> np.ndarray:
@@ -698,7 +697,7 @@ class RunHistory2EPM4EIPS(AbstractRunHistory2EPM):
 
                 # Let's normalize y here
                 # We use the objective_bounds calculated by the runhistory
-                y_ = normalize_costs([run.cost], runhistory.objective_bounds)
+                y_ = normalize_costs(run.cost, runhistory.objective_bounds)
                 y_agg = self.multi_objective_algorithm(y_)
                 y[row, 0] = y_agg
             else:
