@@ -1,7 +1,6 @@
-from logging import Logger
-
 import os
 import shutil
+from logging import Logger
 
 from smac.scenario.scenario import Scenario
 
@@ -10,9 +9,9 @@ __license__ = "3-clause BSD"
 
 
 def create_output_directory(
-        scenario: Scenario,
-        run_id: int,
-        logger: Logger = None,
+    scenario: Scenario,
+    run_id: int,
+    logger: Logger = None,
 ) -> str:
     """Create output directory for this run.
 
@@ -20,9 +19,7 @@ def create_output_directory(
 
     Parameters
     ----------
-
     scenario : ~smac.scenario.scenario.Scenario
-
     run_id : int
 
     Returns
@@ -38,12 +35,14 @@ def create_output_directory(
         return ""
     if os.path.exists(output_dir):
         move_to = output_dir + ".OLD"
-        while (os.path.exists(move_to)):
+        while os.path.exists(move_to):
             move_to += ".OLD"
         shutil.move(output_dir, move_to)
         if logger is not None:
-            logger.warning("Output directory \"%s\" already exists! "
-                           "Moving old folder to \"%s\".",
-                           output_dir, move_to)
+            logger.warning(
+                'Output directory "%s" already exists! ' 'Moving old folder to "%s".',
+                output_dir,
+                move_to,
+            )
     scenario.output_dir_for_this_run = output_dir
     return output_dir
